# Poetry Template

Django app template, using `poetry-python` as dependency manager.

This project is a template that can be cloned and re-used for redistributable apps.

It includes the following:

* `poetry` for dependency management
* `isort`, `black`, `pylint` and `flake8` linting
* `pre-commit` to run linting
* `mypy` for type checking
* `tox` and `travis` for builds and CI

There are default config files for the linting and mypy.
